@@ -19,7 +19,7 @@ class ShellBatch(BaseBatch):
         paths = pathtree.tree(root_dir, {'{name}': {
             '': 'batch_dir',
             'jobs/{job_name}.sh': 'job',
-            'run_{name}.sh': 'run',
+            'run.sh': 'run',
             # optional
             'output/{job_name}.log': 'output',
             'time_generated': 'time_generated',
@@ -33,6 +33,7 @@ MODULE_PRESETS = {
     'cuda10.1': ['cuda/10.1.105', 'cudnn/10.1v7.6.5.32'],
 }
 
+
 class SlurmBatch(BaseBatch):
     '''
 
@@ -41,8 +42,9 @@ class SlurmBatch(BaseBatch):
 
     '''
     default_options = dict(
-        ngpus=0,
-        ncpus=1,
+        n_gpus=0,
+        n_cpus=1,
+        nodes=1,
         conda_env=None,
         run_dir='.',
         conda_version='5.3.1',
@@ -69,14 +71,13 @@ class SlurmBatch(BaseBatch):
         paths = pathtree.tree(root_dir, {'{name}': {
             '': 'batch_dir',
             '{job_name}.sbatch': 'job',
-            'run_{name}.sh': 'run',
+            'run.sh': 'run',
             'slurm/slurm_%j__{job_name}.log': 'output',
             'time_generated': 'time_generated',
         }}).update(name=name, **kw)
         return paths
 
 
-
 class PySlurmBatch(SlurmBatch):
     '''
 
@@ -84,6 +85,7 @@ class PySlurmBatch(SlurmBatch):
     batcher = PySlurmBatch('my.module', m=True)
 
     '''
+
     def __init__(self, cmd, *a, m=False, bin='python', **kw):
         # if isinstance(bin, (int, float)):
         #     bin = 'python{}'.format(bin)
